@@ -452,6 +452,9 @@ int ChangeNumpadToChar(int c)
 
 void EditorCell::ProcessEvent(wxKeyEvent &event)
 {
+  static const wxString chars(wxT("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLNOPQRSTUVWXYZ01234567890_%"));
+  static const wxString delim(wxT("()[]{},.;?/*:=&$"));
+
   if ((event.GetKeyCode() != WXK_DOWN) &&
       (event.GetKeyCode() != WXK_PAGEDOWN) &&
       (event.GetKeyCode() != WXK_PAGEUP) &&
@@ -470,7 +473,54 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
     else
       m_selectionEnd = m_selectionStart = -1;
 
-    if (m_positionOfCaret > 0)
+    if (event.ControlDown()) {
+      if (m_positionOfCaret > 1 &&
+          (chars.Find(m_text[m_positionOfCaret-1]) == wxNOT_FOUND &&
+              chars.Find(m_text[m_positionOfCaret-2]) == wxNOT_FOUND &&
+              delim.Find(m_text[m_positionOfCaret-1]) == wxNOT_FOUND &&
+	      delim.Find(m_text[m_positionOfCaret-2]) == wxNOT_FOUND)) {
+        while (m_positionOfCaret > 0 &&
+              chars.Find(m_text[m_positionOfCaret-1]) == wxNOT_FOUND &&
+              delim.Find(m_text[m_positionOfCaret-1]) == wxNOT_FOUND)
+          m_positionOfCaret--;
+      }
+      else {
+        while (m_positionOfCaret > 0 &&
+            chars.Find(m_text[m_positionOfCaret-1]) == wxNOT_FOUND &&
+            delim.Find(m_text[m_positionOfCaret-1]) == wxNOT_FOUND)
+          m_positionOfCaret--;
+        if (chars.Find(m_text[m_positionOfCaret-1]) != wxNOT_FOUND) {
+          while (m_positionOfCaret > 0 && chars.Find(m_text[m_positionOfCaret-1]) != wxNOT_FOUND)
+            m_positionOfCaret--;
+        }
+        else if (delim.Find(m_text[m_positionOfCaret-1]) != wxNOT_FOUND) {
+          while (m_positionOfCaret > 0 && delim.Find(m_text[m_positionOfCaret-1]) != wxNOT_FOUND)
+            m_positionOfCaret--;
+        }
+        else {
+          while (m_positionOfCaret > 0 &&
+              chars.Find(m_text[m_positionOfCaret-1]) != wxNOT_FOUND &&
+              delim.Find(m_text[m_positionOfCaret-1]) != wxNOT_FOUND)
+            m_positionOfCaret--;
+        }
+      }
+    }
+
+    else if (event.AltDown())
+    {
+      int count=0;
+
+      while (m_positionOfCaret > 0 && count >= 0)
+      {
+        m_positionOfCaret--;
+        if (m_text[m_positionOfCaret]=='(' || m_text[m_positionOfCaret]=='[')
+          count--;
+        else if (m_text[m_positionOfCaret]==')' || m_text[m_positionOfCaret]==']')
+          count++;
+      }
+    }
+
+    else if (m_positionOfCaret > 0)
       m_positionOfCaret--;
 
     if (event.ShiftDown())
@@ -487,7 +537,59 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
     else
       m_selectionEnd = m_selectionStart = -1;
 
-    if (m_positionOfCaret < (signed)m_text.Length())
+    if (event.ControlDown() && m_positionOfCaret < (signed)m_text.Length()-1) {
+      if (m_positionOfCaret < (signed)m_text.Length()-1 &&
+          (chars.Find(m_text[m_positionOfCaret]) == wxNOT_FOUND &&
+              chars.Find(m_text[m_positionOfCaret+1]) == wxNOT_FOUND &&
+              delim.Find(m_text[m_positionOfCaret]) == wxNOT_FOUND &&
+	      delim.Find(m_text[m_positionOfCaret+1]) == wxNOT_FOUND)) {
+        while (m_positionOfCaret < (signed)m_text.Length() &&
+              chars.Find(m_text[m_positionOfCaret]) == wxNOT_FOUND &&
+              delim.Find(m_text[m_positionOfCaret]) == wxNOT_FOUND)
+          m_positionOfCaret++;
+      }
+      else {
+        while (m_positionOfCaret < (signed)m_text.Length() &&
+            chars.Find(m_text[m_positionOfCaret]) == wxNOT_FOUND &&
+            delim.Find(m_text[m_positionOfCaret]) == wxNOT_FOUND)
+          m_positionOfCaret++;
+        if (chars.Find(m_text[m_positionOfCaret]) != wxNOT_FOUND)
+        {
+          while (m_positionOfCaret < (signed)m_text.Length() &&
+              chars.Find(m_text[m_positionOfCaret]) != wxNOT_FOUND)
+            m_positionOfCaret++;
+        }
+        else if (delim.Find(m_text[m_positionOfCaret]) != wxNOT_FOUND)
+        {
+          while (m_positionOfCaret < (signed)m_text.Length() &&
+              delim.Find(m_text[m_positionOfCaret]) != wxNOT_FOUND)
+            m_positionOfCaret++;
+        }
+        else
+        {
+          while (m_positionOfCaret < (signed)m_text.Length() &&
+              chars.Find(m_text[m_positionOfCaret]) != wxNOT_FOUND &&
+              delim.Find(m_text[m_positionOfCaret]) != wxNOT_FOUND)
+            m_positionOfCaret++;
+        }
+      }
+    }
+
+    else if (event.AltDown())
+    {
+      int count=0;
+
+      while (m_positionOfCaret < (signed)m_text.Length() && count >= 0)
+      {
+        m_positionOfCaret++;
+        if (m_text[m_positionOfCaret-1]=='(' || m_text[m_positionOfCaret-1]=='[')
+          count++;
+        else if (m_text[m_positionOfCaret-1]==')' || m_text[m_positionOfCaret-1]==']')
+          count--;
+      }
+    }
+
+    else if (m_positionOfCaret < (signed)m_text.Length())
       m_positionOfCaret++;
 
     if (event.ShiftDown())
@@ -667,10 +769,11 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
 
       /// If deleting ( in () then delete both.
       int right = m_positionOfCaret;
-      if ((m_text.GetChar(m_positionOfCaret-1) == '[' && m_text.GetChar(m_positionOfCaret) == ']') ||
-          (m_text.GetChar(m_positionOfCaret-1) == '(' && m_text.GetChar(m_positionOfCaret) == ')') ||
-          (m_text.GetChar(m_positionOfCaret-1) == '{' && m_text.GetChar(m_positionOfCaret) == '}') ||
-          (m_text.GetChar(m_positionOfCaret-1) == '"' && m_text.GetChar(m_positionOfCaret) == '"'))
+      if (m_positionOfCaret < m_text.Length() &&
+          ((m_text.GetChar(m_positionOfCaret-1) == '[' && m_text.GetChar(m_positionOfCaret) == ']') ||
+              (m_text.GetChar(m_positionOfCaret-1) == '(' && m_text.GetChar(m_positionOfCaret) == ')') ||
+              (m_text.GetChar(m_positionOfCaret-1) == '{' && m_text.GetChar(m_positionOfCaret) == '}') ||
+              (m_text.GetChar(m_positionOfCaret-1) == '"' && m_text.GetChar(m_positionOfCaret) == '"')))
         right++;
       m_text = m_text.SubString(0, m_positionOfCaret - 2) +
                m_text.SubString(right, m_text.Length());
@@ -879,17 +982,20 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
                    m_text.SubString(m_positionOfCaret, m_text.Length());
           break;
         case ')': // jump over ')'
-          if (m_text.GetChar(m_positionOfCaret) == ')')
+          if (m_positionOfCaret < m_text.Length() &&
+              m_text.GetChar(m_positionOfCaret) == ')')
             m_text = m_text.SubString(0, m_positionOfCaret - 2) +
                        m_text.SubString(m_positionOfCaret, m_text.Length());
           break;
         case ']': // jump over ']'
-          if (m_text.GetChar(m_positionOfCaret) == ']')
+          if (m_positionOfCaret < m_text.Length() &&
+              m_text.GetChar(m_positionOfCaret) == ']')
             m_text = m_text.SubString(0, m_positionOfCaret - 2) +
                        m_text.SubString(m_positionOfCaret, m_text.Length());
           break;
         case '}': // jump over '}'
-          if (m_text.GetChar(m_positionOfCaret) == '}')
+          if (m_positionOfCaret < m_text.Length() &&
+              m_text.GetChar(m_positionOfCaret) == '}')
             m_text = m_text.SubString(0, m_positionOfCaret - 2) +
                        m_text.SubString(m_positionOfCaret, m_text.Length());
           break;
@@ -911,10 +1017,18 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
 void EditorCell::FindMatchingParens()
 {
   m_paren2 = m_positionOfCaret;
-  if (wxString(wxT("([{}])")).Find(m_text.GetChar(m_paren2)) == -1)
+  if (m_paren2 < 0)
+  {
+    m_paren1 = m_paren2 = -1;
+    return;
+  }
+
+  if (m_paren2 == m_text.Length() ||
+      wxString(wxT("([{}])")).Find(m_text.GetChar(m_paren2)) == -1)
   {
     m_paren2--;
-    if (wxString(wxT("([{}])")).Find(m_text.GetChar(m_paren2)) == -1)
+    if (m_paren2 < 0 ||
+        wxString(wxT("([{}])")).Find(m_text.GetChar(m_paren2)) == -1)
     {
       m_paren1 = m_paren2 = -1;
       return ;
@@ -1112,9 +1226,9 @@ wxString EditorCell::InterpretEscapeString(wxString txt)
     return L"\x22BC";
   else if (txt == wxT("nor"))
     return L"\x22BD";
-  else if (txt == wxT("implies"))
+  else if (txt == wxT("implies") || txt == wxT("=>"))
     return L"\x21D2";
-  else if (txt == wxT("eq"))
+  else if (txt == wxT("equiv") || txt == wxT("<=>"))
     return L"\x21D4";
   else if (txt == wxT("not"))
     return L"\x00AC";
@@ -1276,7 +1390,7 @@ void EditorCell::SelectPointText(wxDC& dc, wxPoint& point)
   int lineStart = XYToPosition(0, lin);
   m_positionOfCaret = lineStart;
 
-  while (m_text.GetChar(m_positionOfCaret) != '\n' && m_positionOfCaret < (signed)m_text.Length())
+  while (m_positionOfCaret < (signed)m_text.Length() && m_text.GetChar(m_positionOfCaret) != '\n')
   {
     s = m_text.SubString(lineStart, m_positionOfCaret);
     dc.GetTextExtent(m_text.SubString(lineStart, m_positionOfCaret),
@@ -1472,6 +1586,31 @@ bool EditorCell::CutToClipboard()
   return true;
 }
 
+void EditorCell::InsertText(wxString text)
+{
+  SaveValue();
+  m_saveValue = true;
+  m_containsChanges = true;
+
+  if (m_selectionStart > -1)
+  {
+    long start = MIN(m_selectionStart, m_selectionEnd);
+    long end = MAX(m_selectionStart, m_selectionEnd);
+    m_positionOfCaret = start;
+    m_text = m_text.SubString(0, start - 1) +
+             m_text.SubString(end, m_text.Length());
+  }
+  m_text = m_text.SubString(0, m_positionOfCaret - 1) +
+           text +
+           m_text.SubString(m_positionOfCaret, m_text.Length());
+  m_positionOfCaret += text.Length();
+
+  if (GetType() == MC_TYPE_INPUT)
+    FindMatchingParens();
+
+  m_width = m_height = m_maxDrop = m_center = -1;
+}
+
 void EditorCell::PasteFromClipboard(bool primary)
 {
   if (wxTheClipboard->Open())
@@ -1481,31 +1620,10 @@ void EditorCell::PasteFromClipboard(bool primary)
     {
       wxTextDataObject obj;
       wxTheClipboard->GetData(obj);
-
-      SaveValue();
-      m_saveValue = true;
-      m_containsChanges = true;
-
-      if (m_selectionStart > -1)
-      {
-        long start = MIN(m_selectionStart, m_selectionEnd);
-        long end = MAX(m_selectionStart, m_selectionEnd);
-        m_positionOfCaret = start;
-        m_text = m_text.SubString(0, start - 1) +
-                 m_text.SubString(end, m_text.Length());
-      }
-      wxString data = obj.GetText();
-      m_text = m_text.SubString(0, m_positionOfCaret - 1) +
-               data +
-               m_text.SubString(m_positionOfCaret, m_text.Length());
-      m_selectionStart = m_positionOfCaret;
-      m_positionOfCaret += data.Length();
-      m_selectionEnd = m_positionOfCaret;
+      InsertText(obj.GetText());
     }
     wxTheClipboard->Close();
   }
-
-  m_width = m_height = m_maxDrop = m_center = -1;
 }
 
 wxString EditorCell::GetLineString(int line, int start, int end)
@@ -1736,24 +1854,6 @@ bool EditorCell::FindNextTemplate(bool left)
     return true;
   }
 
-  // No template - find a closing paren in the same line.
-  int pos = m_positionOfCaret;
-  while (m_text[pos] != '\n' && pos>0) {
-    // We have a '(' in the current line - jump over the first ')'
-    if (m_text[pos] == '(') {
-      pos = m_positionOfCaret;
-      while (m_text[pos] != '\n' && pos < m_text.Length()) {
-        if (m_text[pos] == ')') {
-          m_positionOfCaret = pos+1;
-          return true;
-        }
-        pos++;
-      }
-      return false;
-    }
-    pos--;
-  }
-  // No '(' was found in the current line - regular TAB.
   return false;
 }
 
