@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 #include "ExptCell.h"
 #include "TextCell.h"
 
+#define EXPT_DEC 2
+
 ExptCell::ExptCell() : MathCell()
 {
   m_baseCell = NULL;
@@ -118,7 +120,7 @@ void ExptCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
   if (m_isBroken)
     m_powCell->RecalculateWidths(parser, fontsize, true);
   else
-    m_powCell->RecalculateWidths(parser, MAX(MC_MIN_SIZE, fontsize - 3), true);
+    m_powCell->RecalculateWidths(parser, MAX(MC_MIN_SIZE, fontsize - EXPT_DEC), true);
   m_width = m_baseCell->GetFullWidth(scale) + m_powCell->GetFullWidth(scale) -
             SCALE_PX(MC_TEXT_PADDING, scale);
   m_exp->RecalculateWidths(parser, fontsize, true);
@@ -134,7 +136,7 @@ void ExptCell::RecalculateSize(CellParser& parser, int fontsize, bool all)
   if (m_isBroken)
     m_powCell->RecalculateSize(parser, fontsize, true);
   else
-    m_powCell->RecalculateSize(parser, MAX(MC_MIN_SIZE, fontsize - 3), true);
+    m_powCell->RecalculateSize(parser, MAX(MC_MIN_SIZE, fontsize - EXPT_DEC), true);
   m_height = m_baseCell->GetMaxHeight() + m_powCell->GetMaxHeight() -
              SCALE_PX((8 * fontsize) / 10 + MC_EXP_INDENT, scale);
   m_center = m_powCell->GetMaxHeight() + m_baseCell->GetMaxCenter() -
@@ -159,7 +161,7 @@ void ExptCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
     pw.y = point.y - m_baseCell->GetMaxCenter() - m_powCell->GetMaxHeight()
            + m_powCell->GetMaxCenter() +
            SCALE_PX((8 * fontsize) / 10 + MC_EXP_INDENT, scale);
-    m_powCell->Draw(parser, pw, MAX(MC_MIN_SIZE, fontsize - 3), true);
+    m_powCell->Draw(parser, pw, MAX(MC_MIN_SIZE, fontsize - EXPT_DEC), true);
   }
 
   MathCell::Draw(parser, point, fontsize, all);
@@ -206,7 +208,7 @@ wxString ExptCell::ToXML(bool all)
 	if (m_isBroken)
 		return wxEmptyString;
 	return _T("<e><r>") + m_baseCell->ToXML(true) + _T("</r><r>") +
-			m_powCell->ToXML(true) + _T("</r></e>") + 
+			m_powCell->ToXML(true) + _T("</r></e>") +
 			MathCell::ToXML(all);
 }
 
