@@ -124,6 +124,8 @@ wxString FunCell::ToString(bool all)
 {
   if (m_isBroken)
     return wxEmptyString;
+  if (m_altCopyText != wxEmptyString)
+    return m_altCopyText + MathCell::ToString(all);
   wxString s = m_nameCell->ToString(true) + m_argCell->ToString(true);
   s += MathCell::ToString(all);
   return s;
