@@ -159,7 +159,7 @@ void GroupCell::ResetInputLabel(bool all)
 
   // reset the next cell
   if (all && m_next)
-    ((GroupCell *)m_next)->ResetInputLabel(true);
+    dynamic_cast<GroupCell*>(m_next)->ResetInputLabel(true);
 }
 
 MathCell* GroupCell::Copy(bool all)
@@ -596,16 +596,28 @@ wxString GroupCell::ToString(bool all)
 
 wxString GroupCell::PrepareForTeX(wxString str)
 {
-  str.Replace(wxT("\\"), wxT("\\verb|\\|"));
-  str.Replace(wxT("_"), wxT("\\_"));
-  str.Replace(wxT("%"), wxT("\\%"));
-  str.Replace(wxT("{"), wxT("\\{"));
-  str.Replace(wxT("}"), wxT("\\}"));
-  str.Replace(wxT("^"), wxT("\\verb|^|"));
-  str.Replace(wxT(">"), wxT("\\verb|>|"));
-  str.Replace(wxT("<"), wxT("\\verb|<|"));
+#if !wxUSE_UNICODE
+  wxString str1(str.wc_str(wxConvLocal), wxConvUTF8);
+#else
+  wxString str1(str);
+#endif
 
-  return str;
+  str1.Replace(wxT("\\"), wxT("\\verb|\\|"));
+  str1.Replace(wxT("_"), wxT("\\_"));
+  str1.Replace(wxT("%"), wxT("\\%"));
+  str1.Replace(wxT("{"), wxT("\\{"));
+  str1.Replace(wxT("}"), wxT("\\}"));
+  str1.Replace(wxT("^"), wxT("\\verb|^|"));
+  str1.Replace(wxT(">"), wxT("\\verb|>|"));
+  str1.Replace(wxT("<"), wxT("\\verb|<|"));
+
+#if !wxUSE_UNICODE
+  wxString str2(str1.wc_str(wxConvUTF8), wxConvLocal);
+#else
+  wxString str2(str1);
+#endif
+
+  return str2;
 }
 
 wxString GroupCell::ToTeX(bool all)
@@ -654,7 +666,7 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
     // Input cells
     str = wxT("\n\\noindent\n%%%%%%%%%%%%%%%\n")
           wxT("%%% INPUT:\n")
-          wxT("\\begin{minipage}[t]{1.5cm}{\\color{red}\\bf\n")
+          wxT("\\begin{minipage}[t]{8ex}{\\color{red}\\bf\n")
           wxT("\\begin{verbatim}\n") +
           m_input->ToString(false) +
           wxT("\n\\end{verbatim}}\n\\end{minipage}");
@@ -696,7 +708,7 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
 
             if (bmp.ToFile(file))
               str += wxT("\\includegraphics[width=9cm]{") +
-                  filename + wxT("_img/") + image + wxT("}\n");
+                  filename + wxT("_img/") + image + wxT("}");
           }
           else
             str << wxT("\n\\verb|<<GRAPHICS>>|\n");
@@ -706,7 +718,7 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
         {
           if (str.Right(13) != wxT("displaystyle\n"))
             str += wxT("\n\\end{math}\n\n\\begin{math}\\displaystyle\n");
-          str += wxT("\\mathrm{\\color{labelcolor}") + tmp->ToTeX(false) + wxT("}\\quad");
+          str += wxT("\\parbox{8ex}{\\color{labelcolor}") + tmp->ToTeX(false) + wxT("}\n");
         }
 
         else
@@ -827,7 +839,7 @@ wxString GroupCell::ToXML(bool all)
         GroupCell *tmp = m_hiddenTree;
         while (tmp) {
           str += tmp->ToXML(false);
-          tmp = (GroupCell *)tmp->m_next;
+          tmp = dynamic_cast<GroupCell*>(tmp->m_next);
         }
         str += wxT("</fold>");
       }
@@ -961,21 +973,16 @@ bool GroupCell::SetEditableContent(wxString text)
     return false;
 }
 
-MathCell *GroupCell::GetEditable()
+EditorCell *GroupCell::GetEditable()
 {
   switch (m_groupType) {
     case GC_TYPE_CODE:
-      return GetInput();
     case GC_TYPE_IMAGE:
-      return GetInput();
     case GC_TYPE_TEXT:
-      return GetInput();
     case GC_TYPE_TITLE:
-      return GetInput();
     case GC_TYPE_SECTION:
-      return GetInput();
     case GC_TYPE_SUBSECTION:
-      return GetInput();
+      return dynamic_cast<EditorCell*>(GetInput());
     case GC_TYPE_PAGEBREAK:
     default:
       return NULL;
@@ -1074,12 +1081,12 @@ void GroupCell::Hide(bool hide) {
   {
     if (m_hide == false) {
       if ((m_groupType == GC_TYPE_TEXT) || (m_groupType == GC_TYPE_CODE))
-        ((EditorCell *)GetEditable())->SetFirstLineOnly(true);
+        GetEditable()->SetFirstLineOnly(true);
       m_hide = true;
     }
     else {
       if ((m_groupType == GC_TYPE_TEXT) || (m_groupType == GC_TYPE_CODE))
-        ((EditorCell *)GetEditable())->SetFirstLineOnly(false);
+        GetEditable()->SetFirstLineOnly(false);
       m_hide = false;
     }
 
@@ -1116,16 +1123,16 @@ GroupCell *GroupCell::Fold() {
     return NULL;
   if (m_next == NULL)
     return NULL;
-  int nextgct = ((GroupCell *)m_next)->GetGroupType(); // groupType of the next cell
+  int nextgct = dynamic_cast<GroupCell*>(m_next)->GetGroupType(); // groupType of the next cell
   if ((m_groupType == nextgct) || IsLesserGCType(nextgct))
     return NULL; // if the next gc shouldn't be folded, exit
 
   // now there is at least one cell to fold (at least m_next)
-  GroupCell *end = (GroupCell *)m_next;
+  GroupCell *end = dynamic_cast<GroupCell*>(m_next);
   GroupCell *start = end; // first to fold
 
   while (end) {
-    GroupCell *tmp = (GroupCell *)end->m_next;
+    GroupCell *tmp = dynamic_cast<GroupCell*>(end->m_next);
     if (tmp == NULL)
       break;
     if ((m_groupType == tmp->GetGroupType()) || IsLesserGCType(tmp->GetGroupType()))
@@ -1167,7 +1174,7 @@ GroupCell *GroupCell::Unfold() {
     next->m_previous = next->m_previousToDraw = tmp;
 
   m_hiddenTree = NULL;
-  return (GroupCell *)tmp;
+  return dynamic_cast<GroupCell*>(tmp);
 }
 
 GroupCell *GroupCell::FoldAll(bool all) {
@@ -1181,7 +1188,7 @@ GroupCell *GroupCell::FoldAll(bool all) {
     result = NULL;
 
   if (all && m_next)
-    return ((GroupCell *)m_next)->FoldAll(true);
+    return dynamic_cast<GroupCell*>(m_next)->FoldAll(true);
   else
     return result;
 }
@@ -1190,7 +1197,7 @@ GroupCell *GroupCell::FoldAll(bool all) {
 // if (all) then also calls it on it's m_next
 GroupCell *GroupCell::UnfoldAll(bool all) {
   if (all && m_next)
-    ((GroupCell *)m_next)->UnfoldAll(true);
+    dynamic_cast<GroupCell*>(m_next)->UnfoldAll(true);
 
   if (!IsFoldable() || !m_hiddenTree)
     return NULL;
@@ -1253,8 +1260,7 @@ void GroupCell::Number(int &section, int &subsection, int &image) {
     case GC_TYPE_IMAGE:
       image++;
       {
-        wxString num = _("Figure");
-        num << wxT(" ") << image << wxT(":");
+        wxString num = wxString::Format(_("Figure %d:"), image);
         ((TextCell*)m_input)->SetValue(num);
       }
       break;
@@ -1266,7 +1272,7 @@ void GroupCell::Number(int &section, int &subsection, int &image) {
     m_hiddenTree->Number(section, subsection, image);
 
   if (m_next)
-    ((GroupCell *)m_next)->Number(section, subsection, image);
+    dynamic_cast<GroupCell*>(m_next)->Number(section, subsection, image);
 }
 
 bool GroupCell::IsMainInput(MathCell *active)
