@@ -24,6 +24,7 @@
 #include <wx/textfile.h>
 
 #include "MathCell.h"
+#include "EditorCell.h"
 #include "GroupCell.h"
 #include "EvaluationQueue.h"
 #include "Autocomplete.h"
@@ -144,7 +145,7 @@ public:
   bool ActivatePrevInput();
   bool ActivateNextInput(bool input = false);
   void ScrollToCell(MathCell *cell);
-  MathCell* GetActiveCell()
+  EditorCell* GetActiveCell()
   {
     return m_activeCell;
   }
@@ -158,7 +159,7 @@ public:
   }
   void SetWorkingGroup(GroupCell *group);
   bool IsSelectionInWorking();
-  void SetActiveCell(MathCell *cell, bool callRefresh = true);
+  void SetActiveCell(EditorCell *cell, bool callRefresh = true);
   void SetHCaret(MathCell *where, bool callRefresh = true); // call with false, when manually refreshing
   GroupCell *GetHCaret();
   void OpenHCaret(wxString txt = wxEmptyString, int type = GC_TYPE_CODE);
@@ -191,10 +192,12 @@ public:
   void Replace(wxString oldString, wxString newString);
   int ReplaceAll(wxString oldString, wxString newString);
   wxString GetInputAboveCaret();
-  bool LoadSymbols(wxString file) { m_autocomplete.LoadSymbols(file); }
+  bool LoadSymbols(wxString file) { return m_autocomplete.LoadSymbols(file); }
   bool Autocomplete(bool templates = false);
   void AddSymbol(wxString fun, bool templ = false) { m_autocomplete.AddSymbol(fun, templ); }
   void SetActiveCellText(wxString text);
+  bool InsertText(wxString text);
+  GroupCell *GetWorkingGroup() { return m_workingGroup; }
 protected:
   MathCell* CopySelection();
   MathCell* CopySelection(MathCell* start, MathCell* end, bool asData = false);
@@ -236,7 +239,7 @@ protected:
   MathCell *m_selectionEnd;
   int m_clickType;
   GroupCell *m_clickInGC;
-  MathCell *m_activeCell;
+  EditorCell *m_activeCell;
   CellParser *m_selectionParser;
   bool m_switchDisplayCaret;
   bool m_editingEnabled;
