@@ -34,8 +34,6 @@ TextCell::TextCell(wxString text) : MathCell()
   m_text.Replace(wxT("\n"), wxEmptyString);
   m_highlight = false;
   m_altJs = m_alt = false;
-
-  SetAltText();
 }
 
 TextCell::~TextCell()
@@ -50,8 +48,6 @@ void TextCell::SetValue(wxString text)
   m_width = -1;
   m_text.Replace(wxT("\n"), wxEmptyString);
   m_alt = m_altJs = false;
-
-  SetAltText();
 }
 
 MathCell* TextCell::Copy(bool all)
@@ -64,7 +60,6 @@ MathCell* TextCell::Copy(bool all)
   tmp->m_isHidden = m_isHidden;
   tmp->m_textStyle = m_textStyle;
   tmp->m_highlight = m_highlight;
-  tmp->SetAltText();
   if (all && m_next != NULL)
     tmp->AppendCell(m_next->Copy(all));
   return tmp;
@@ -77,6 +72,8 @@ void TextCell::Destroy()
 
 void TextCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
 {
+  SetAltText(parser);
+
   if (m_height == -1 || m_width == -1 || fontsize != m_fontSize || parser.ForceUpdate())
   {
     m_fontSize = fontsize;
@@ -238,6 +235,17 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
                           m_fontname : parser.GetFontName(m_textStyle),
                       parser.GetFontEncoding()));
 
+  // Titles, sections, subsections - don't underline
+  else if ((m_textStyle == TS_TITLE) ||
+           (m_textStyle == TS_SECTION) ||
+           (m_textStyle == TS_SUBSECTION))
+    dc.SetFont(wxFont(fontsize1, wxFONTFAMILY_MODERN,
+                      parser.IsItalic(m_textStyle),
+                      parser.IsBold(m_textStyle),
+                      false,
+                      parser.GetFontName(m_textStyle),
+                      parser.GetFontEncoding()));
+
   // Default
   else
     dc.SetFont(wxFont(fontsize1, wxFONTFAMILY_MODERN,
@@ -257,7 +265,11 @@ bool TextCell::IsOperator()
 
 wxString TextCell::ToString(bool all)
 {
-  wxString text = m_text;
+  wxString text;
+  if (m_altCopyText != wxEmptyString)
+    text = m_altCopyText;
+  else
+    text = m_text;
   if (m_textStyle == TS_STRING)
     text = wxT("\"") + text + wxT("\"");
   return text + MathCell::ToString(all);
@@ -372,8 +384,12 @@ bool TextCell::IsShortNum()
   return false;
 }
 
-void TextCell::SetAltText()
+void TextCell::SetAltText(CellParser& parser)
 {
+  m_altJs = m_alt = false;
+  if (m_textStyle == TS_DEFAULT)
+    return ;
+
   /// Greek characters are defined in jsMath, Windows and Unicode
   if (m_textStyle == TS_GREEK_CONSTANT)
   {
@@ -396,7 +412,7 @@ void TextCell::SetAltText()
     m_altJsText = GetSymbolTeX();
     if (m_altJsText != wxEmptyString)
     {
-      if (m_text == wxT("+") || m_text == wxT("-") || m_text == wxT("="))
+      if (m_text == wxT("+") || m_text == wxT("="))
         m_texFontname = wxT("jsMath-cmr10");
       else if (m_text == wxT("%pi"))
         m_texFontname = wxT("jsMath-cmmi10");
@@ -405,11 +421,11 @@ void TextCell::SetAltText()
       m_altJs = true;
     }
 #if wxUSE_UNICODE
-    m_altText = GetSymbolUnicode();
+    m_altText = GetSymbolUnicode(parser.CheckKeepPercent());
     if (m_altText != wxEmptyString)
       m_alt = true;
 #elif defined __WXMSW__
-    m_altText = GetSymbolSymbol();
+    m_altText = GetSymbolSymbol(parser.CheckKeepPercent());
     if (m_altText != wxEmptyString)
     {
       m_alt = true;
@@ -533,12 +549,10 @@ wxString TextCell::GetGreekStringUnicode()
   return wxEmptyString;
 }
 
-wxString TextCell::GetSymbolUnicode()
+wxString TextCell::GetSymbolUnicode(bool keepPercent)
 {
   if (m_text == wxT("+"))
     return wxT("+");
-  else if (m_text == wxT("-"))
-    return wxT("-");
   else if (m_text == wxT("="))
     return wxT("=");
   else if (m_text == wxT("inf"))
@@ -561,7 +575,7 @@ wxString TextCell::GetSymbolUnicode()
     return wxString(L" \x22BD ");
   else if (m_text == wxT(" implies "))
     return wxString(L" \x21D2 ");
-  else if (m_text == wxT(" eq "))
+  else if (m_text == wxT(" equiv "))
     return wxString(L" \x21D4 ");
   else if (m_text == wxT("not"))
     return wxString(L"\x00AC");
@@ -571,6 +585,14 @@ wxString TextCell::GetSymbolUnicode()
   else if (m_textStyle == TS_SPECIAL_CONSTANT && m_text == wxT("d"))
     return wxString(L"\x2202");
   */
+
+  if (!keepPercent) {
+    if (m_text == wxT("%e"))
+      return wxString(L"e");
+    else if (m_text == wxT("%i"))
+      return wxString(L"i");
+  }
+
   return wxEmptyString;
 }
 
@@ -689,7 +711,7 @@ wxString TextCell::GetGreekStringSymbol()
   return wxEmptyString;
 }
 
-wxString TextCell::GetSymbolSymbol()
+wxString TextCell::GetSymbolSymbol(bool keepPercent)
 {
   if (m_text == wxT("inf"))
     return wxT("\xA5");
@@ -713,11 +735,18 @@ wxString TextCell::GetSymbolSymbol()
     return wxT("\xAF");
   else if (m_text == wxT(" implies "))
     return wxT("\xDE");
-  else if (m_text == wxT(" eq "))
+  else if (m_text == wxT(" equiv "))
     return wxT("\xDB");
   else if (m_text == wxT(" xor "))
     return wxT("\xC5");
 
+  if (!keepPercent) {
+    if (m_text == wxT("%e"))
+      return wxString(L"e");
+    else if (m_text == wxT("%i"))
+      return wxString(L"i");
+  }
+
   return wxEmptyString;
 }
 
@@ -842,8 +871,6 @@ wxString TextCell::GetSymbolTeX()
     return wxT("\x31");
   else if (m_text == wxT("+"))
     return wxT("+");
-  else if (m_text == wxT("-"))
-    return wxT("\x7B");
   else if (m_text == wxT("%pi"))
     return wxT("\xD9");
   else if (m_text == wxT("="))
