@@ -167,6 +167,8 @@ protected:
   bool OpenWXMXFile(wxString file, MathCtrl *document, bool clearDocument = true);
   GroupCell* CreateTreeFromXMLNode(wxXmlNode *xmlcells, wxString wxmxfilename = wxEmptyString);
   GroupCell* CreateTreeFromWXMCode(wxArrayString *wxmLines);
+  bool SaveFile(bool forceSave = false);
+  int SaveDocumentP();
 
   wxSocketBase *m_client;
   wxSocketServer *m_server;
@@ -208,6 +210,9 @@ protected:
   wxFindReplaceData m_findData;
   wxRegEx m_funRegEx;
   wxRegEx m_varRegEx;
+#if wxUSE_DRAG_AND_DROP
+  friend class MyDropTarget;
+#endif
   DECLARE_EVENT_TABLE()
 };
 
