@@ -31,19 +31,21 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
     wxFrame(parent, id, title, pos, size, wxDEFAULT_FRAME_STYLE)
 {
   m_manager.SetManagedWindow(this);
-
   // console
   m_console = new MathCtrl(this, -1, wxDefaultPosition, wxDefaultSize);
 
   // history
   m_history = new History(this, -1);
 
+  m_plotSlider = NULL;
+
   SetupMenu();
 #if defined (__WXMSW__) || defined (__WXGTK20__) || defined (__WXMAC__)
   SetupToolBar();
 #endif
 
-  frame_1_statusbar = CreateStatusBar(2);
+
+  CreateStatusBar(2);
   int widths[] =
     {
       -1, 300
@@ -68,7 +70,11 @@ wxMaximaFrame::~wxMaximaFrame()
   wxString perspective = m_manager.SavePerspective();
 
   wxConfig::Get()->Write(wxT("AUI/perspective"), perspective);
+#if defined __WXMAC__
+  wxConfig::Get()->Write(wxT("AUI/toolbar"), (GetToolBar()->IsShown()));
+#else
   wxConfig::Get()->Write(wxT("AUI/toolbar"), (GetToolBar() != NULL));
+#endif
 
   m_manager.UnInit();
 }
@@ -82,11 +88,15 @@ void wxMaximaFrame::set_properties()
   icon += wxT("/share/wxMaxima/wxmaxima.png");
   SetIcon(wxIcon(icon, wxBITMAP_TYPE_PNG));
 #endif
+#ifndef __WXMAC__
   SetTitle(wxString::Format(_("wxMaxima %s "), wxT(VERSION)) + _("[ unsaved ]"));
+#else
+  SetTitle(_("untitled"));
+#endif
 
   m_console->SetBackgroundColour(wxColour(wxT("WHITE")));
   m_console->SetMinSize(wxSize(100, 100));
-  frame_1_statusbar->SetStatusText(_("Welcome to wxMaxima"), 0);
+  SetStatusText(_("Welcome to wxMaxima"), 0);
 }
 
 void wxMaximaFrame::do_layout()
@@ -155,7 +165,7 @@ void wxMaximaFrame::do_layout()
 
 void wxMaximaFrame::SetupMenu()
 {
-  frame_1_menubar = new wxMenuBar();
+  wxMenuBar *frame_1_menubar = new wxMenuBar();
 
 #if defined __WXGTK20__
   wxMenuItem *tmp_menu_item;
@@ -171,17 +181,25 @@ void wxMaximaFrame::SetupMenu()
   // File menu
   wxMenu* wxglade_tmp_menu_1 = new wxMenu;
 #if defined __WXMAC__
-  wxglade_tmp_menu_1->Append(mac_newId, _("&New Window\tCtrl-N"),
+  wxglade_tmp_menu_1->Append(mac_newId, _("New\tCtrl-N"),
 			     _("Open a new window"));
+#else
+  APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_new_id, _("New\tCtrl-N"),
+		   _("Open a new window"), wxT("gtk-new"));
 #endif
   APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_open_id, _("&Open...\tCtrl-O"),
                    _("Open a document"), wxT("gtk-open"));
   m_recentDocumentsMenu = new wxMenu();
   wxglade_tmp_menu_1->Append(menu_recent_documents, _("Open Recent"), m_recentDocumentsMenu);
+#if defined __WXMAC__
+  wxglade_tmp_menu_1->AppendSeparator();
+  wxglade_tmp_menu_1->Append(mac_closeId, _("Close\tCtrl-W"),
+           _("Close window"), wxITEM_NORMAL);
+#endif
   APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_save_id, _("&Save\tCtrl-S"),
                    _("Save document"), wxT("gtk-save"));
   APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_save_as_id, _("Save As...\tShift-Ctrl-S"),
-                   _("Save document as"), wxT("gtk-save"));
+		   _("Save document as"), wxT("gtk-save"));
   wxglade_tmp_menu_1->Append(menu_load_id, _("&Load Package...\tCtrl-L"),
                              _("Load a Maxima package file"), wxITEM_NORMAL);
   wxglade_tmp_menu_1->Append(menu_batch_id, _("&Batch File...\tCtrl-B"),
@@ -287,7 +305,13 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2->Append(menu_add_pagebreak, _("Insert Page Break\tF10"),
                              _("Insert a page break"));
   wxglade_tmp_menu_2->Append(menu_insert_image, _("Insert Image..."),
-                              _("Insert image"), wxITEM_NORMAL);
+                             _("Insert image"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->AppendSeparator();
+  wxglade_tmp_menu_2->Append(menu_history_previous, _("Previous Command\tAlt-Up"),
+                             _("Recall previous command from history"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_history_next, _("Next Command\tAlt-Down"),
+                             _("Recall next command from history"), wxITEM_NORMAL);
+
   frame_1_menubar->Append(wxglade_tmp_menu_2, _("&Cell"));
 
   // Maxima menu
@@ -562,7 +586,7 @@ void wxMaximaFrame::SetupMenu()
                                   _("Convert exponential function of imaginary argument to trigonometric form"),
 				  wxITEM_NORMAL);
   wxglade_tmp_menu_5_sub3->Append(menu_exponentialize, _("&Exponentialize"),
-                                  _("Conver trigonometric functions to exponential form"),
+                                  _("Convert trigonometric functions to exponential form"),
 				  wxITEM_NORMAL);
   wxglade_tmp_menu_5->Append(wxNewId(), _("&Complex Simplification"),
                              wxglade_tmp_menu_5_sub3,
@@ -628,6 +652,10 @@ void wxMaximaFrame::SetupMenu()
                              _("Info about Maxima build"), wxITEM_NORMAL);
   wxglade_tmp_menu_7->Append(menu_bug_report, _("&Bug Report"),
                              _("Report bug"), wxITEM_NORMAL);
+  wxglade_tmp_menu_7->AppendSeparator();
+  wxglade_tmp_menu_7->Append(menu_check_updates, _("Check for Updates"),
+                             _("Check if a newer version of wxMaxima/Maxima exist."),
+                             wxITEM_NORMAL);
 #ifndef __WXMAC__
   wxglade_tmp_menu_7->AppendSeparator();
 #endif
@@ -709,6 +737,7 @@ void wxMaximaFrame::SetupToolBar()
                            IMAGE("help.png"),
                            _("Show Maxima help"));
   frame_1_toolbar->Realize();
+
   SetToolBar(frame_1_toolbar);
 }
 
@@ -818,9 +847,12 @@ void wxMaximaFrame::UpdateRecentDocuments()
 {
   for (int i=menu_recent_document_0; i<= menu_recent_document_9; i++)
   {
-    wxMenuItem *item = m_recentDocumentsMenu->Remove(i);
-    delete item;
-    item = NULL;
+    if (m_recentDocumentsMenu->FindItem(i) != NULL)
+    {
+      wxMenuItem *item = m_recentDocumentsMenu->Remove(i);
+      delete item;
+      item = NULL;
+    }
 
     if (i-menu_recent_document_0 < (signed)m_recentDocuments.Count())
     {
@@ -954,26 +986,26 @@ wxPanel* wxMaximaFrame::CreateStatPane()
 #endif
   int sizerBorder = 2;
 
-  grid1->Add(new wxButton(panel, menu_stats_mean, _("Mean")), 0, style, border);
-  grid1->Add(new wxButton(panel, menu_stats_median, _("Median")), 0, style, border);
-  grid1->Add(new wxButton(panel, menu_stats_var, _("Variance")), 0, style, border);
-  grid1->Add(new wxButton(panel, menu_stats_dev, _("Deviation")), 0, style, border);
+  grid1->Add(new wxButton(panel, menu_stats_mean, _("Mean...")), 0, style, border);
+  grid1->Add(new wxButton(panel, menu_stats_median, _("Median...")), 0, style, border);
+  grid1->Add(new wxButton(panel, menu_stats_var, _("Variance...")), 0, style, border);
+  grid1->Add(new wxButton(panel, menu_stats_dev, _("Deviation...")), 0, style, border);
 
   box->Add(grid1, 0, style, sizerBorder);
 
   box1->Add(new wxButton(panel, menu_stats_tt1, _("Mean Test...")), 0, style, border);
   box1->Add(new wxButton(panel, menu_stats_tt2, _("Mean Difference Test...")), 0, style, border);
-  box1->Add(new wxButton(panel, menu_stats_tnorm, _("Normality Test")), 0, style, border);
-  box1->Add(new wxButton(panel, menu_stats_linreg, _("Linear Regression")), 0, style, border);
+  box1->Add(new wxButton(panel, menu_stats_tnorm, _("Normality Test...")), 0, style, border);
+  box1->Add(new wxButton(panel, menu_stats_linreg, _("Linear Regression...")), 0, style, border);
   box1->Add(new wxButton(panel, menu_stats_lsquares, _("Least Squares Fit...")), 0, style, border);
 
   box->Add(box1, 0, style, sizerBorder);
 
   grid2->Add(new wxButton(panel, menu_stats_histogram, _("Histogram...")), 0, style, border);
   grid2->Add(new wxButton(panel, menu_stats_scatterplot, _("Scatterplot...")), 0, style, border);
-  grid2->Add(new wxButton(panel, menu_stats_barsplot, _("Barsplot")), 0, style, border);
-  grid2->Add(new wxButton(panel, menu_stats_piechart, _("Piechart")), 0, style, border);
-  grid2->Add(new wxButton(panel, menu_stats_boxplot, _("Boxplot")), 0, style, border);
+  grid2->Add(new wxButton(panel, menu_stats_barsplot, _("Barsplot...")), 0, style, border);
+  grid2->Add(new wxButton(panel, menu_stats_piechart, _("Piechart...")), 0, style, border);
+  grid2->Add(new wxButton(panel, menu_stats_boxplot, _("Boxplot...")), 0, style, border);
 
   box->Add(grid2, 0, style, sizerBorder);
 
@@ -1021,6 +1053,10 @@ wxPanel *wxMaximaFrame::CreateFormatPane()
 
 void wxMaximaFrame::ShowToolBar(bool show)
 {
+#if defined __WXMAC__
+  wxToolBar *tbar = GetToolBar();
+  tbar->Show(show);
+#else
   if (show) {
     if (GetToolBar() == NULL)
       SetupToolBar();
@@ -1033,5 +1069,6 @@ void wxMaximaFrame::ShowToolBar(bool show)
       SetToolBar(NULL);
     }
   }
+#endif
 }
 
