@@ -37,6 +37,7 @@ enum {
   socket_server_id,
   plot_slider_id,
   input_line_id,
+  menu_new_id,
   menu_open_id,
   menu_batch_id,
   menu_save_id,
@@ -213,6 +214,7 @@ enum {
 #if defined (__WXMAC__)
   mac_newId,
   mac_openId,
+  mac_closeId,
 #endif
   menu_recent_documents,
   menu_recent_document_0,
@@ -229,7 +231,6 @@ enum {
   menu_pane_hideall,
   menu_pane_math,
   menu_pane_history,
-  menu_pane_inspector,
   menu_pane_format,
   menu_pane_stats,
   menu_stats_mean,
@@ -297,12 +298,9 @@ protected:
   void LoadRecentDocuments();
   void SaveRecentDocuments();
   wxAuiManager m_manager;
-  wxMenuBar* frame_1_menubar;
 
   MathCtrl* m_console;
   History * m_history;
-  wxStatusBar* frame_1_statusbar;
-  wxToolBar* frame_1_toolbar;
   wxSlider* m_plotSlider;
   wxArrayString m_recentDocuments;
   wxMenu* m_recentDocumentsMenu;
